.. image:: https://img.shields.io/pypi/v/pye3d.svg
   :target: `PyPI link`_

.. image:: https://img.shields.io/pypi/pyversions/pye3d.svg
   :target: `PyPI link`_

.. _PyPI link: https://pypi.org/project/pye3d

.. image:: https://github.com/pupil-labs/pye3d-detector/actions/workflows/build-pye3d.yml/badge.svg
   :target: https://github.com/pupil-labs/pye3d-detector/actions/workflows/build-pye3d.yml
   :alt: Build pye3d

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
   :alt: Code style: Black

.. image:: https://readthedocs.org/projects/pye3d-detector/badge/?version=latest
   :target: https://pye3d-detector.readthedocs.io/en/latest/?badge=latest

.. image:: https://img.shields.io/badge/skeleton-2021-informational
   :target: https://blog.jaraco.com/skeleton


pye3d Detector
##############

``pye3d`` implements a published mathematical 3D eye model capturing ocular kinematics
and optics (see `Swirski and Dodgson, 2013`_, as well as `Dierkes, Kassner, and Bulling, 2019`_.

.. _Swirski and Dodgson, 2013: https://www.researchgate.net/publication/264658852_A_fully-automatic_temporal_approach_to_single_camera_glint-free_3D_eye_model_fitting
.. _Dierkes, Kassner, and Bulling, 2019: https://www.researchgate.net/publication/333490770_A_fast_approach_to_refraction-aware_eye-model_fitting_and_gaze_prediction

Installation
------------

We recommend installing the pre-packaged binary wheels from PyPI:

.. code-block:: console

    pip install pye3d

For more information see the `documentation <https://pye3d-detector.readthedocs.io>`_.
